@@ -2,6 +2,7 @@
 package Module::Install::CustomInstallationPath;
 
 use strict;
+use 5.005;
 use File::HomeDir;
 use Config;
 
@@ -10,16 +11,14 @@ use vars qw( @ISA $VERSION );
 use Module::Install::Base;
 @ISA = qw( Module::Install::Base );
 
-$VERSION = sprintf "%d.%02d%02d", q/0.10.30/ =~ /(\d+)/g;
+$VERSION = sprintf "%d.%02d%02d", q/0.10.40/ =~ /(\d+)/g;
 
 # ---------------------------------------------------------------------------
 
-sub Check_Custom_Installation
+sub check_custom_installation
 {
   my $self = shift;
 
-  # Module::Install says it requires perl 5.004
-  $self->requires( perl => '5.004' );
   $self->include_deps('File::HomeDir',0);
 
   return if (grep {/^PREFIX=/} @ARGV) || (grep {/^INSTALLDIRS=/} @ARGV);
@@ -48,5 +47,4 @@ sub Check_Custom_Installation
 
 # ---------------------------------------------------------------------------
 
-#line 105
-
+#line 109
